@@ -268,10 +268,14 @@ def initialization(width, height, thr):
         # Images filtered to be used only on first iteration
         GPU.img1_g = temp_manager.array([height, width],
             np.float32, dependencies = [GPU.subImg1_1,
-            GPU.subImg1_2])
+            GPU.subImg1_2, GPU.u_index_1, GPU.v_index_1])
         GPU.img2_g = temp_manager.array([height, width],
             np.float32, dependencies = [GPU.subImg1_1,
-            GPU.subImg1_2, GPU.img1_g])
+            GPU.subImg1_2, GPU.u_index_1, GPU.v_index_1,
+            GPU.img1_g])
+        #img_g = np.float32(np.zeros([height,width]))
+        #GPU.img1_g = thr.empty_like(img_g)
+        #GPU.img2_g = thr.empty_like(img_g)
 
     # Initialice all GPU variables for second iteration (only done once)
     GPU.subImg2_1 = temp_manager.array([N_boxes_2,
@@ -362,7 +366,6 @@ def initialization(width, height, thr):
         GPU.dv_dy_2, GPU.temp_dx_2, GPU.temp_dy_2,
         GPU.u_index_2])
 
-
     # Load mask if any
     if Parameters.mask:
         GPU.mask = thr.to_device(Parameters.Data.mask)
@@ -443,11 +446,11 @@ def processing(img1_name, img2_name, thr):
     N_pixels_1 = N_boxes_1*Parameters.box_size_1_x*Parameters.box_size_1_y
     N_pixels_2 = N_boxes_2*Parameters.box_size_2_x*Parameters.box_size_2_y
 
-    #Set to zero the required variables
-    GPU.ini_index(GPU.u_index_1, GPU.v_index_2, local_size = None,
+    # Set to zero the velocity index, as long as the can be initialized from
+    # second pass due to shared memory
+    GPU.ini_index(GPU.u_index_1, GPU.v_index_1, local_size = None,
             global_size = N_pixels_1)
 
-
     # Mask images if required
     if Parameters.mask:
         # Reserved to implement the mask
@@ -462,6 +465,7 @@ def processing(img1_name, img2_name, thr):
                 local_size = None, global_size = grid.pixels)
         GPU.gaussian_filter(GPU.img2_g, GPU.img2, GPU.kernel, GPU.data1,
                 local_size = None, global_size = grid.pixels)
+        thr.synchronize()
 
         # Obtain SubImage
         GPU.Slice(GPU.subImg1_1, GPU.img1_g, GPU.box_origin_x_1, GPU.box_origin_y_1,
